# replacements [![NPM version](https://badge.fury.io/js/replacements.svg)](http://badge.fury.io/js/replacements)  [![Build Status](https://travis-ci.org/jonschlinkert/replacements.svg)](https://travis-ci.org/jonschlinkert/replacements) 

> Transform a string with an array of replacement patterns.

## Install with [npm](npmjs.org)

```bash
npm i replacements --save
```

## Usage

```js
var replace = require('replacements');
```

### object of replacement patterns

```js
var transformers = {
  pattern: /a/g,
  replacement: 'bbb'
};
console.log(replace('aaa', transformers));
//=> 'bbbbbbbbb'
```

### key-value replacement patterns

For basic string transformations, you can pass the string to replace as the key, and the replacement as a value:

```js
var transformers = {
  'a': 'b'
  'c': 'd'
};
console.log(replace('aaabbbccc', transformers));
//=> 'bbbbbbddd'
```

_Note that only the first matching string will only be replaced using this format. If you need more flexibility, use the pattern-replacement regex syntax._.

### array of replacement patterns

```js
var transformers = [
  {pattern: /a/g, replacement: 'bbb'},
  {pattern: /b/g, replacement: 'ccc'},
  {pattern: /c/g, replacement: 'ddd'},
  {pattern: /d/g, replacement: 'eee'},
  {pattern: /[e]+/g, replacement: '_DONE_'}
];
console.log(replace('aaa', transformers));
//=> '__DONE__'
```

### functions as replacements

```js
var transformers = {
  pattern: /a+/g,
  replacement: function(match) {
    return match.split('').map(function(str, i) {
      if (i === 0) {return 'b'; }
      if (i === 1) {return str.toUpperCase();}
      return str;
    }).join('');
  }
};
console.log(replace('aaa', transformers));
//=> 'bAa'
```

## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2014-2015 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on March 13, 2015._